@@ -24,10 +24,14 @@
 #include <stdio.h>
 #include <unistd.h>
 #include <stdlib.h>
-#include <getopt.h>
 #include "wmgeneral.h"
 #include "config.h"
 
+#ifdef HAVE_GETOPT_LONG
+#include <getopt.h>
+#endif
+
+
 /*******************************************************************************\
 |* AddRcKey		  						        |
 \*******************************************************************************/
@@ -154,8 +158,7 @@ void ParseCMDLine(int argc, char *argv[])
 	char *cmdline, *p;
 	int  i, c;
 
-	while(1)
-	{
+#ifdef HAVE_GETOPT_LONG
 		static struct option long_options[] =
 		{
 			{"alarmint",required_argument,NULL,'A'},
@@ -172,7 +175,17 @@ void ParseCMDLine(int argc, char *argv[])
 			{"windowed",no_argument,NULL,'w'},
 			{0, 0, 0, 0}
 		};
-		if ((c = getopt_long(argc, argv, "A:b:B:C:d:hlL:U:vVw", long_options, NULL)) == -1)
+		
+		#define GETOPTFUNC(x,y,z) getopt_long(x,y,"-" z, long_options, NULL)
+		#define GETOPTENDCHAR -1
+#else   /* ! HAVE_GETOPT_LONG */
+		#define GETOPTFUNC(x,y,z) getopt(x,y,z)
+		#define GETOPTENDCHAR EOF
+#endif
+
+	while(1)
+	{
+	  if ((c=GETOPTFUNC (argc, argv, "A:b:B:C:d:hlL:U:vVw")) == GETOPTENDCHAR)
 			break;
 
 		switch (c)
