@@ -310,8 +310,9 @@ int main(int argc, char *argv[]) {
 				*  Blink red "C" on/off ...
 				*/
 				if (Toggle||(BlinkRate == 0.0)) {
-					if (Beep)
+				/*	if (Beep)
 						XBell(display, Volume);
+				*/
 					copyXPMArea(110,  6, 5, 7,  6,  7);
 				} else
 					copyXPMArea(98,  6, 5, 7,  6,  7);
@@ -336,8 +337,9 @@ int main(int argc, char *argv[]) {
 						*  Blink red battery [TODO : and digital %age] on/off...
 						*/
 						if (Toggle||(BlinkRate == 0.0)) {
-							if (Beep)
+							/* if (Beep)
 								XBell(display, Volume);
+							*/
 							/* Toggle = OFF; */
 							copyXPMArea(99, 20, 12, 7, 30, 50);
 						} else{
@@ -351,9 +353,9 @@ int main(int argc, char *argv[]) {
 						*/
 						if (Toggle||(BlinkRate == 0.0)) {
 							
-							if (Beep) 
+							/* if (Beep) 
 								XBell(display, Volume);
-							
+							*/
 							/* Toggle = OFF; */
 							copyXPMArea(99, 20, 12, 7, 30, 50);
 							
@@ -368,9 +370,9 @@ int main(int argc, char *argv[]) {
 						*/
 	      				if (Toggle||(BlinkRate == 0.0)) {
 							
-							if (Beep)
+							/* if (Beep)
 								XBell(display, Volume);
-
+							*/
 							copyXPMArea(99, 20, 12, 7, 30, 50); 
 							
 						} else
